@@ -3,21 +3,24 @@ package ZHOUYI::ZhanPu;
 use strict;
 use warnings;
 use ZHOUYI;
+use utf8;
 
 our @ISA    = qw(Exporter);
 our @EXPORT = qw(pu qigua jiegua );
 
+=encoding utf8
+
 =head1 NAME
 
 ZHOUYI::ZhanPu - A util of ZHOUYI modules，divination to judge for the future using YI's Gua(卦) or tuan（彖）info (周易占卜)!
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 =head1 SYNOPSIS
 
